@@ -274,11 +274,18 @@ class Covid:
                         'last_update': 1583893094000
                     }
         """
+
         country = filter(
-            lambda country: country["name"] == country_name.title(),
+            lambda country: country["name"].lower() == country_name.lower(),
             self.list_countries(),
         )
-        country = next(country)
+        try:
+            country = next(country)
+        except StopIteration:
+            raise ValueError(
+                f"There is no country called '{country_name}', to check available country names use `list_countries()`"
+            )
+
         url = self.__country_url(country["id"])
         response = requests.get(url).json()
 
